@@ -24,6 +24,7 @@ DEALINGS IN THE SOFTWARE.
 from starlette.applications import Starlette
 from starlette.middleware import Middleware
 from starlette.middleware.sessions import SessionMiddleware
+from starlette.middleware.httpsredirect import HTTPSRedirectMiddleware
 from starlette_wtf import CSRFProtectMiddleware
 
 from secrets import token_urlsafe
@@ -40,7 +41,7 @@ from .routes import ROUTES, ERROR_HANDLERS
 from .http_middleware import APIMiddleware
 
 
-__version__ = "0.0.3"
+__version__ = "0.0.4"
 
 
 MAP_IMAGES = {
@@ -79,6 +80,8 @@ class SQLMatches(Starlette):
             Optionally pass your own url safe secret key.
         map_images: dict
             Key as actual map name, value as image name.
+        kwargs
+            Additional parameters to pass to the Starlette instance.
         """
 
         startup_tasks = [self._startup]
@@ -90,19 +93,14 @@ class SQLMatches(Starlette):
         if "on_shutdown" in kwargs:
             shutdown_tasks = shutdown_tasks + kwargs["on_shutdown"]
 
-        middlewares = []
+        middlewares = [
+            Middleware(SessionMiddleware, secret_key=secret_key),
+            Middleware(CSRFProtectMiddleware, csrf_secret=csrf_secret),
+            Middleware(APIMiddleware),
+            Middleware(HTTPSRedirectMiddleware)
+        ]
         if "middleware" in kwargs:
-            middlewares = kwargs["middleware"]
-
-        middlewares.append(
-            Middleware(SessionMiddleware, secret_key=secret_key)
-        )
-        middlewares.append(
-            Middleware(CSRFProtectMiddleware, csrf_secret=csrf_secret)
-        )
-        middlewares.append(
-            Middleware(APIMiddleware)
-        )
+            middlewares = middlewares + kwargs["middleware"]
 
         if "routes" in kwargs:
             routes = kwargs["routes"] + ROUTES
